@@ -11,6 +11,7 @@ from basinmaker.addlakeandobs.definelaketypeqgis import (
 from basinmaker.addlakeandobs.filterlakesqgis import select_lakes_by_area_r
 from basinmaker.addlakeandobs.pourpointsqgis import define_pour_points_with_lakes
 from basinmaker.addlakeandobs.modifyfdr import modify_lakes_flow_direction
+from basinmaker.addlakeandobs.modifystr import modify_str_r_to_add_sub_in_head_str
 
 
 def add_lakes_into_existing_watershed_delineation(
@@ -89,9 +90,17 @@ def add_lakes_into_existing_watershed_delineation(
         grass.run_command(
             "g.copy", rast=("cat1_OL", pourpoints_with_lakes), overwrite=True
         )
-        grass.run_command("g.copy", rast=(fdr_grass, nfdr_grass), overwrite=True)
 
-        return
+        lake_outflow_pourpoints = '#'
+        grass.run_command(
+            "g.copy", rast=(cat_no_lake, cat_use_default_acc), overwrite=True
+        )
+        grass.run_command(
+            "g.copy", rast=(cat_no_lake, cat_add_lake), overwrite=True
+        )
+        grass.run_command("g.copy", rast=(fdr_grass, nfdr_grass), overwrite=True)
+        grass.run_command("g.copy", rast=(fdr_arcgis, nfdr_arcgis), overwrite=True)
+        return lake_outflow_pourpoints
 
     preprocessing_lake_polygon(
         path_lakefile_in=path_lakefile_in,
@@ -190,6 +199,18 @@ def add_lakes_into_existing_watershed_delineation(
         sl_lakes=sl_lakes,
         sl_str_connected_lake=sl_str_connected_lake,
     )
+    
+    modify_str_r_to_add_sub_in_head_str(
+        grass = grass,
+        garray = garray,
+        con = con,
+        str_r = str_r,
+        str_v = str_v,
+        connected_lake = connected_lake,
+        cat_no_lake = cat_no_lake,
+        fdr_grass = fdr_grass,
+        max_memroy = max_memroy,      
+    )
 
     Lakes_WIth_Multi_Outlet, Remove_Str = define_pour_points_with_lakes(
         grass=grass,
@@ -231,9 +252,12 @@ def add_lakes_into_existing_watershed_delineation(
 
 
     cat_withlake_array = garray.array(mapname=cat_add_lake_old_fdr)
+    cat_withlake_array = cat_withlake_array.astype(int)
     fdr_arcgis_array = garray.array(mapname=fdr_arcgis)
+    fdr_arcgis_array = fdr_arcgis_array.astype(int)
     str_r_array = garray.array(mapname=str_r)
     sl_lakes_array = garray.array(mapname=sl_lakes)
+    sl_lakes_array = sl_lakes_array.astype(int)
     acc_array = garray.array(mapname=acc)
     ncols = int(cat_withlake_array.shape[1])
     nrows = int(cat_withlake_array.shape[0])
@@ -372,4 +396,4 @@ def add_lakes_into_existing_watershed_delineation(
     )
 
     PERMANENT.close()
-    return
+    return lake_outflow_pourpoints
